#line 1 "Engine/csound_orclex.c"

#line 3 "Engine/csound_orclex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define csound_orc_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer csound_orc_create_buffer
#endif

#ifdef yy_delete_buffer
#define csound_orc_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer csound_orc_delete_buffer
#endif

#ifdef yy_scan_buffer
#define csound_orc_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer csound_orc_scan_buffer
#endif

#ifdef yy_scan_string
#define csound_orc_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string csound_orc_scan_string
#endif

#ifdef yy_scan_bytes
#define csound_orc_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes csound_orc_scan_bytes
#endif

#ifdef yy_init_buffer
#define csound_orc_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer csound_orc_init_buffer
#endif

#ifdef yy_flush_buffer
#define csound_orc_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer csound_orc_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define csound_orc_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state csound_orc_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define csound_orc_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer csound_orc_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define csound_orcpush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state csound_orcpush_buffer_state
#endif

#ifdef yypop_buffer_state
#define csound_orcpop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state csound_orcpop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define csound_orcensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack csound_orcensure_buffer_stack
#endif

#ifdef yylex
#define csound_orclex_ALREADY_DEFINED
#else
#define yylex csound_orclex
#endif

#ifdef yyrestart
#define csound_orcrestart_ALREADY_DEFINED
#else
#define yyrestart csound_orcrestart
#endif

#ifdef yylex_init
#define csound_orclex_init_ALREADY_DEFINED
#else
#define yylex_init csound_orclex_init
#endif

#ifdef yylex_init_extra
#define csound_orclex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra csound_orclex_init_extra
#endif

#ifdef yylex_destroy
#define csound_orclex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy csound_orclex_destroy
#endif

#ifdef yyget_debug
#define csound_orcget_debug_ALREADY_DEFINED
#else
#define yyget_debug csound_orcget_debug
#endif

#ifdef yyset_debug
#define csound_orcset_debug_ALREADY_DEFINED
#else
#define yyset_debug csound_orcset_debug
#endif

#ifdef yyget_extra
#define csound_orcget_extra_ALREADY_DEFINED
#else
#define yyget_extra csound_orcget_extra
#endif

#ifdef yyset_extra
#define csound_orcset_extra_ALREADY_DEFINED
#else
#define yyset_extra csound_orcset_extra
#endif

#ifdef yyget_in
#define csound_orcget_in_ALREADY_DEFINED
#else
#define yyget_in csound_orcget_in
#endif

#ifdef yyset_in
#define csound_orcset_in_ALREADY_DEFINED
#else
#define yyset_in csound_orcset_in
#endif

#ifdef yyget_out
#define csound_orcget_out_ALREADY_DEFINED
#else
#define yyget_out csound_orcget_out
#endif

#ifdef yyset_out
#define csound_orcset_out_ALREADY_DEFINED
#else
#define yyset_out csound_orcset_out
#endif

#ifdef yyget_leng
#define csound_orcget_leng_ALREADY_DEFINED
#else
#define yyget_leng csound_orcget_leng
#endif

#ifdef yyget_text
#define csound_orcget_text_ALREADY_DEFINED
#else
#define yyget_text csound_orcget_text
#endif

#ifdef yyget_lineno
#define csound_orcget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno csound_orcget_lineno
#endif

#ifdef yyset_lineno
#define csound_orcset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno csound_orcset_lineno
#endif

#ifdef yyget_column
#define csound_orcget_column_ALREADY_DEFINED
#else
#define yyget_column csound_orcget_column
#endif

#ifdef yyset_column
#define csound_orcset_column_ALREADY_DEFINED
#else
#define yyset_column csound_orcset_column
#endif

#ifdef yywrap
#define csound_orcwrap_ALREADY_DEFINED
#else
#define yywrap csound_orcwrap
#endif

#ifdef yyget_lval
#define csound_orcget_lval_ALREADY_DEFINED
#else
#define yyget_lval csound_orcget_lval
#endif

#ifdef yyset_lval
#define csound_orcset_lval_ALREADY_DEFINED
#else
#define yyset_lval csound_orcset_lval
#endif

#ifdef yyget_lloc
#define csound_orcget_lloc_ALREADY_DEFINED
#else
#define yyget_lloc csound_orcget_lloc
#endif

#ifdef yyset_lloc
#define csound_orcset_lloc_ALREADY_DEFINED
#else
#define yyset_lloc csound_orcset_lloc
#endif

#ifdef yyalloc
#define csound_orcalloc_ALREADY_DEFINED
#else
#define yyalloc csound_orcalloc
#endif

#ifdef yyrealloc
#define csound_orcrealloc_ALREADY_DEFINED
#else
#define yyrealloc csound_orcrealloc
#endif

#ifdef yyfree
#define csound_orcfree_ALREADY_DEFINED
#else
#define yyfree csound_orcfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 101
#define YY_END_OF_BUFFER 102
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[410] =
    {   0,
        0,    0,   93,   93,   91,   91,   97,   97,    0,    0,
        0,    0,    0,    0,  102,  100,   88,    3,    1,   17,
       82,   36,   12,   35,    4,    5,   10,    8,   16,    9,
      100,   11,   86,   86,   15,   24,   31,   32,   14,  100,
       85,   85,    6,  100,    7,   13,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,  100,   34,
       38,   37,  100,   88,   36,   86,   86,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,  101,   93,   95,   94,   91,   90,   97,   99,   98,
       76,   74,   75,   76,   77,   78,   81,   79,   80,   80,

       88,   17,   17,   19,   36,   36,    0,   12,   12,   35,
       35,   20,    4,    4,   10,   10,   29,    8,    8,   27,
       16,   16,    9,    9,   28,   18,   87,   11,   11,   30,
       87,   86,    0,    0,    0,   24,   24,   22,   25,   31,
       31,   26,   32,   32,   33,   23,   14,   14,    0,   40,
        0,   41,   42,   84,   85,   66,    6,    6,    0,    2,
        0,   13,   13,   55,   85,   85,   52,   85,   43,   85,
       85,   85,   85,   62,   85,   85,   85,   56,   85,   61,
       85,   85,   85,   72,   34,   34,   21,   38,   38,   37,
       37,   37,   88,    0,    0,    0,    0,   86,    0,    0,

        0,    0,    0,   85,   66,   55,   85,   85,   52,   85,
       43,   85,   85,   85,   85,   62,   85,   85,   85,   56,
       85,   61,   85,   85,   85,   93,   94,   91,   90,   97,
       98,   73,   77,   78,   79,   79,   80,   19,   19,    0,
       20,   20,   29,   29,   27,   27,   28,   28,    0,   30,
       30,   87,    0,   87,   87,    0,   22,   22,   25,   25,
       26,   26,   33,   33,   23,   23,    0,   39,   84,   84,
        0,   85,   85,   85,   44,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   21,   21,    0,    0,
        0,   71,   87,   87,    0,   85,   85,   85,   85,   85,

       85,   85,   85,   85,   85,   85,   85,   85,   85,    0,
        0,   87,    0,   50,   85,   85,   85,   58,   44,   44,
       85,   85,   85,   85,   85,   85,   85,   85,   45,   85,
       85,    0,    0,    0,   50,   85,   85,   85,   58,   85,
       85,   85,   85,   85,   85,   85,   85,   45,   85,   85,
        0,   83,   85,   51,   68,   70,   85,   59,   67,   46,
       60,   63,   47,   85,   85,   53,   54,   92,    0,   83,
       85,   51,   68,   70,   85,   59,   67,   46,   60,   63,
       47,   85,   85,   53,   54,    0,   48,   85,   64,   69,
        0,   48,   85,   64,   69,   89,   49,   85,   85,   96,

       85,   85,   49,   49,   57,   65,   57,   65,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,    1,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   20,
       20,   21,   20,   20,   20,   20,   20,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   30,   30,   31,   30,
       32,   32,   32,   33,   33,   32,   32,   32,   33,   33,
       32,   32,   33,   32,   32,   33,   32,   34,   32,   32,
       35,   36,   37,   38,   39,    1,   40,   41,   42,   43,

       44,   45,   46,   47,   48,   33,   49,   50,   51,   52,
       53,   54,   32,   55,   56,   57,   58,   32,   59,   34,
       32,   32,   60,   61,   62,   63,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,   64,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   65,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[66] =
    {   0,
        1,    2,    1,    1,    2,    1,    1,    2,    1,    1,
        3,    1,    1,    4,    4,    4,    5,    4,    6,    6,
        6,    7,    4,    4,    4,    4,    4,    4,    6,    6,
        6,    8,    9,    8,   10,    4,   10,    4,    8,   11,
        6,    6,    6,    6,   11,    8,    8,    9,    9,    8,
        8,    8,    9,    9,    8,    8,    9,    8,    8,    1,
        1,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[422] =
    {   0,
        0,   65,  129,  133,  137,  141,  162,  227,  137,  141,
      291,    0,  348,    0, 1100, 1206,  174, 1206, 1206,  175,
     1206,  185,  179,  191,  202, 1206,  240,  244,  206,  248,
      193,  252,  241,  282, 1206,  292,  261,  302,  213,  350,
      126, 1088,  265,  277, 1206,  306,  144,  260,  172,  191,
      308,  318,  175,  346,  140,  174,  304,  267, 1038,  356,
      374,  389, 1033,  382,  401,  390,  406,  397,  237,  409,
      418,  419,  421,  427,  425,  424,  433,  431,  441,  437,
      443, 1206,  187, 1206,  394,  456,  472,  473, 1206,    0,
     1206, 1206, 1206, 1033,  492,    0, 1206,  493, 1206,    0,

      497,  498, 1206,  502,  506, 1206, 1044,  510, 1206,  514,
     1206,  518,  522, 1206,  526, 1206,  530,  534, 1206,  538,
      542, 1206,  546, 1206,  550, 1206,  537,  557, 1206,  561,
      551,  556,  564,    0, 1052,  586, 1206,  591,  596,  600,
     1206,  604,  608, 1206,  612,  616,  620, 1206,  622,  609,
      629, 1206, 1206,  630, 1081, 1080,  634, 1206,  642, 1206,
     1086,  649, 1206, 1077,  458,  148, 1074,  195, 1072,  245,
      466,  369,  265, 1070,  371,  495,  499, 1069,  519, 1068,
      351,  428,  556, 1206,  653, 1206,  657,  661, 1206,  665,
     1206,  669,  671,  316,  552, 1030,  625,    0,  678,  575,

      668,  674,  679,  434,  543,  568,  675,  687,  635,  688,
      689,  691,  701,  711,  710,  713,  714,  715,  717,  716,
      718,  730,  731,  732,  737,  744,  687,  745,  747,  767,
        0, 1206,  768,    0,  774, 1206,    0,  778, 1206, 1015,
      785, 1206,  789, 1206,  793, 1206,  797, 1206,  787,  807,
     1206,  794,  797,  800,    0,  979,  821, 1206,  825, 1206,
      829, 1206,  834, 1206,  838, 1206,  840,  827,  847, 1206,
     1012,  609,  818,  681,  851,  740,  794,  760,  800,  472,
      811,  822,  782,  833,  629,  847,  860, 1206,  957,  955,
      936, 1206,  267,    0,  739,  856,  853,  857,  858,  859,

      861,  862,  866,  880,  871,  876,  881,  896,  903,  897,
      875,  907,  887,  888,  893,  615,  878,  929,  929, 1206,
      897,  901,  902,  898,  605,  906,  910,  507,  879,  911,
      924,  842,  731,  920,  930,  935,  937,  944,  951,  952,
      953,  959,  960,  961,  966,  973,  978,  968,  975,  982,
      738, 1206,  954,  767,  763,  744,  928,  627,  601,  597,
      575,  527,  523,  936,  958,  453,  449, 1206,  344,  981,
      990,  998, 1005, 1008, 1011, 1017, 1018, 1020, 1021, 1023,
     1025, 1026, 1027, 1030, 1033,  363,  295, 1003, 1035,  208,
      166, 1039, 1042, 1045, 1043, 1206, 1055,  956, 1048, 1206,

     1051, 1055, 1067, 1206,  187,  122, 1064, 1065, 1206, 1103,
     1114, 1125, 1134, 1144, 1151, 1160, 1168, 1174, 1177, 1183,
     1194
    } ;

static const flex_int16_t yy_def[422] =
    {   0,
      409,  409,  410,  410,  410,  410,  411,  411,  412,  412,
      410,   11,  410,   13,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      413,  413,  409,  409,  409,  409,  413,  413,  413,  413,
      413,  413,  413,  413,  413,  413,  413,  413,  409,  409,
      409,  409,  409,  414,  409,  415,  415,  416,  416,  416,
      416,  416,  416,  416,  416,  416,  416,  416,  416,  416,
      416,  409,  409,  409,  409,  409,  409,  409,  409,  417,
      409,  409,  409,  409,  409,  418,  409,  409,  409,  419,

      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  420,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  413,  413,  409,  409,  409,  409,
      421,  409,  409,  413,  413,  413,  413,  413,  413,  413,
      413,  413,  413,  413,  413,  413,  413,  413,  413,  413,
      413,  413,  413,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  414,  409,  415,  409,  409,   67,  409,  415,

      415,   67,  415,  416,  416,  416,  416,  416,  416,  416,
      416,  416,  416,  416,  416,  416,  416,  416,  416,  416,
      416,  416,  416,  416,  416,  409,  409,  409,  409,  409,
      417,  409,  409,  418,  409,  409,  419,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  420,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      421,  413,  413,  413,  409,  413,  413,  413,  413,  413,
      413,  413,  413,  413,  413,  413,  409,  409,  409,  409,
      409,  409,  201,  202,  415,  416,  416,  416,  416,  416,

      416,  416,  416,  416,  416,  416,  416,  416,  416,  409,
      409,  409,  409,  413,  413,  413,  413,  413,  409,  409,
      413,  413,  413,  413,  413,  413,  413,  413,  413,  413,
      413,  409,  409,  415,  416,  416,  416,  416,  416,  416,
      416,  416,  416,  416,  416,  416,  416,  416,  416,  416,
      409,  409,  413,  413,  413,  413,  413,  413,  413,  413,
      413,  413,  413,  413,  413,  413,  413,  409,  409,  415,
      416,  416,  416,  416,  416,  416,  416,  416,  416,  416,
      416,  416,  416,  416,  416,  409,  413,  413,  413,  413,
      409,  416,  416,  416,  416,  409,  409,  413,  413,  409,

      416,  416,  409,  409,  413,  413,  416,  416,    0,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409
    } ;

static const flex_int16_t yy_nxt[1272] =
    {   0,
       16,   17,   18,   19,   17,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       34,   35,   16,   36,   37,   38,   39,   40,   41,   42,
       42,   42,   42,   42,   43,   44,   45,   46,   42,   42,
       42,   42,   47,   48,   49,   50,   42,   51,   52,   42,
       42,   53,   54,   42,   42,   55,   56,   57,   58,   59,
       60,   16,   61,   62,   63,   16,   64,   18,   19,   64,
       20,   21,   65,   23,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   66,   67,   67,   35,   16,   36,   37,
       38,   39,   40,   68,   69,   69,   69,   69,   69,   43,

       44,   45,   46,   69,   69,   69,   69,   70,   71,   72,
       73,   69,   74,   75,   69,   69,   76,   77,   69,   69,
       78,   79,   80,   81,   59,   60,   16,   61,   62,   63,
       83,   84,  154,   83,   83,   84,  154,   83,   86,   92,
       93,   86,   86,   92,   93,   86,  156,   85,   85,   85,
      154,   85,   85,   85,  154,   87,   87,   87,  154,   87,
       87,   87,   82,   88,   89,   82,   88,   82,   82,   82,
       82,   82,   82,   82,   82,  101,  102,  103,  101,  102,
      108,  109,  154,  108,  154,  154,  105,  106,  226,  105,
      273,  226,  110,  111,  180,  110,  164,  154,   94,  104,

      112,  154,   94,  113,  114,  154,  113,  121,  122,  400,
      121,  127,  127,  127,  147,  148,  177,  147,  154,  167,
      181,   82,   82,   82,   82,   82,   82,   82,   88,   89,
       82,   88,   82,   82,   82,   82,   82,   82,   82,   82,
      107,  115,  116,  168,  115,  118,  119,  154,  118,  123,
      124,  274,  123,  128,  129,  154,  128,  131,  199,  132,
      132,  132,  140,  141,  117,  140,  157,  158,  120,  157,
      154,  133,  125,  126,  134,  154,  130,  154,  159,  160,
      409,  159,  409,  135,  133,  142,   82,   82,   82,   82,
       82,   82,   95,  136,  137,   95,  136,  276,  131,  161,

      132,  132,  132,  143,  144,  397,  143,  162,  163,  165,
      162,  166,  133,  183,  154,  138,  139,  279,  154,   96,
       96,   96,   96,   96,   96,  133,  145,  146,  154,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       97,  149,  169,  170,  149,  182,  154,  185,  186,  171,
      185,  154,   98,  173,  172,  196,   99,  396,  150,  150,
      150,  289,  174,  175,  176,  188,  189,  151,  188,  154,
      100,  154,  100,  193,  100,  391,  193,  100,  178,  194,
      190,  191,  100,  190,  284,  100,  100,  152,  153,  179,

      100,  100,  105,  106,  100,  105,  131,  154,  198,  198,
      198,  199,  227,  227,  227,  278,  187,  205,  199,  154,
      201,  280,  131,  202,  198,  198,  198,  199,  154,  154,
      199,  154,  203,  201,  154,  154,  201,  154,  154,  199,
      199,  154,  199,  154,  154,  199,  199,  154,  199,  201,
      196,  154,  199,  154,  199,  199,  197,  228,  199,  154,
      228,  206,  199,  154,  199,  219,  209,  207,  154,  208,
      215,  211,  212,  210,  230,  220,  154,  230,  213,  216,
      217,  218,  154,  214,  285,  222,  221,  223,  224,  225,
      229,  229,  229,  233,  235,  236,  233,  235,  101,  102,

      103,  101,  102,  238,  239,  154,  238,  105,  106,  154,
      105,  108,  109,  272,  108,  110,  111,  154,  110,  241,
      242,  277,  241,  113,  114,  325,  113,  115,  116,  154,
      115,  243,  244,  154,  243,  118,  119,  154,  118,  245,
      246,  281,  245,  121,  122,  282,  121,  123,  124,  365,
      123,  247,  248,  154,  247,  127,  127,  127,  128,  129,
      283,  128,  250,  251,  199,  250,  154,  249,  409,  252,
      252,  252,  131,  199,  132,  132,  132,  253,  154,  253,
      249,  133,  254,  254,  254,  154,  133,  136,  137,  199,
      136,  409,  257,  258,  133,  257,  199,  259,  260,  133,

      259,  140,  141,  286,  140,  261,  262,  154,  261,  143,
      144,  154,  143,  263,  264,  154,  263,  265,  266,  154,
      265,  147,  148,  149,  147,  154,  149,  150,  150,  150,
      267,  269,  270,  267,  269,  157,  158,  154,  157,  154,
      150,  150,  150,  159,  160,  154,  159,  268,  268,  268,
      162,  163,  314,  162,  185,  186,  199,  185,  287,  288,
      362,  287,  188,  189,  161,  188,  190,  191,  356,  190,
      190,  191,  193,  190,  240,  193,  330,  291,  194,  292,
      292,  253,  292,  253,  409,  154,  293,  293,  293,  199,
      409,  154,  294,  294,  294,  409,  199,  154,  154,  275,

      199,  154,  294,  294,  294,  227,  227,  227,  199,  199,
      199,  154,  199,  294,  294,  294,  294,  294,  294,  295,
      154,  154,  199,  154,  154,  154,  154,  154,  154,  297,
      296,  199,  199,  318,  199,  199,  199,  199,  199,  199,
      154,  154,  154,  299,  298,  226,  228,  154,  226,  228,
      154,  199,  199,  199,  154,  409,  300,  301,  199,  306,
      199,  304,  302,  305,  303,  229,  229,  229,  230,  233,
      154,  230,  233,  154,  307,  235,  236,  154,  235,  238,
      239,  386,  238,  334,  309,  369,  241,  242,  308,  241,
      243,  244,  154,  243,  245,  246,  321,  245,  247,  248,

      311,  247,  311,  323,  154,  312,  312,  312,  250,  251,
      154,  250,  252,  252,  252,  254,  254,  254,  254,  254,
      254,  154,  257,  258,  133,  257,  259,  260,  154,  259,
      261,  262,  154,  261,  328,  263,  264,  133,  263,  265,
      266,  267,  265,  154,  267,  268,  268,  268,  269,  270,
      322,  269,  319,  320,  326,  319,  324,  154,  268,  268,
      268,  287,  288,  154,  287,  315,  154,  154,  154,  154,
      316,  154,  154,  327,  199,  317,  154,  199,  199,  199,
      199,  154,  199,  199,  329,  368,  154,  199,  154,  154,
      154,  154,  199,  312,  312,  312,  331,  199,  154,  335,

      336,  199,  199,  154,  342,  337,  154,  154,  154,  339,
      338,  154,  154,  154,  340,  341,  154,  199,  343,  344,
      154,  154,  346,  345,  199,  312,  312,  312,  347,  357,
      319,  320,  348,  319,  154,  353,  409,  354,  154,  154,
      154,  199,  352,  349,  355,  154,  154,  154,  351,  358,
      361,  199,  350,  360,  154,  359,  199,  363,  199,  364,
      366,  154,  154,  154,  154,  199,  154,  367,  154,  154,
      154,  154,  199,  199,  199,  370,  154,  371,  154,  372,
      199,  199,  199,  154,  388,  154,  373,  199,  154,  199,
      374,  389,  154,  333,  199,  375,  199,  409,  387,  199,

      154,  390,  199,  199,  376,  405,  332,  377,  154,  291,
      378,  199,  379,  154,  160,  154,  380,  381,  154,  199,
      383,  154,  382,  313,  384,  385,  199,  154,  154,  199,
      154,  154,  199,  154,  392,  154,  154,  154,  199,  199,
      154,  199,  199,  154,  199,  154,  199,  199,  199,  397,
      398,  199,  154,  154,  199,  154,  403,  404,  154,  403,
      199,  154,  310,  199,  199,  154,  199,  393,  403,  404,
      395,  403,  199,  399,  154,  154,  199,  290,  154,  154,
      154,  394,  275,  402,  154,  199,  199,  154,  160,  401,
      154,  154,  256,  240,  232,  406,  192,  184,  154,  409,

      407,  409,  408,   82,   82,   82,   82,   82,   82,   82,
       82,   82,   82,   82,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   91,   91,   91,   91,   91,
       91,   91,   91,   91,   91,   91,  155,  409,  409,  155,
      409,  155,  155,  409,  155,  195,  409,  409,  409,  195,
      409,  195,  195,  409,  195,  200,  200,  200,  200,  200,
      409,  200,  204,  409,  409,  204,  204,  204,  204,  409,
      204,  231,  231,  231,  231,  231,  231,  231,  231,  234,
      409,  234,  234,  409,  234,  237,  237,  237,  255,  409,
      409,  409,  409,  255,  271,  271,  271,  271,  271,  271,

      271,  271,  271,  271,  271,   15,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409
    } ;

static const flex_int16_t yy_chk[1272] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,

        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        3,    3,  406,    3,    4,    4,   41,    4,    5,    9,
        9,    5,    6,   10,   10,    6,   41,    3,    3,    3,
       55,    4,    4,    4,   47,    5,    5,    5,  166,    6,
        6,    6,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,   17,   20,   20,   17,   20,
       23,   23,   49,   23,   56,   53,   22,   22,   83,   22,
      166,   83,   24,   24,   55,   24,   47,  405,    9,   20,

       24,   50,   10,   25,   25,  168,   25,   29,   29,  391,
       29,   31,   31,   31,   39,   39,   53,   39,  390,   49,
       56,    7,    7,    7,    7,    7,    7,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
       22,   27,   27,   50,   27,   28,   28,   69,   28,   30,
       30,  168,   30,   32,   32,  170,   32,   33,   69,   33,
       33,   33,   37,   37,   27,   37,   43,   43,   28,   43,
       48,   33,   30,   30,   33,  173,   32,   58,   44,   44,
      293,   44,  293,   33,   33,   37,    8,    8,    8,    8,
        8,    8,   11,   36,   36,   11,   36,  170,   34,   44,

       34,   34,   34,   38,   38,  387,   38,   46,   46,   48,
       46,   48,   34,   58,   57,   36,   36,  173,   51,   11,
       11,   11,   11,   11,   11,   34,   38,   38,   52,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       13,   40,   51,   51,   40,   57,   54,   60,   60,   51,
       60,  181,   13,   52,   51,  194,   13,  386,   40,   40,
       40,  194,   52,   52,   52,   61,   61,   40,   61,  172,
       13,  175,   13,   64,   13,  369,   64,   13,   54,   64,
       62,   62,   13,   62,  181,   13,   13,   40,   40,   54,

       13,   13,   65,   65,   13,   65,   66,   68,   66,   66,
       66,   66,   85,   85,   85,  172,   60,   68,   68,   70,
       66,  175,   67,   66,   67,   67,   67,   67,   71,   72,
       70,   73,   66,   66,   76,   75,   67,   74,  182,   71,
       72,   78,   73,   77,  204,   76,   75,   80,   74,   67,
       65,   79,   78,   81,   77,  204,   65,   86,   80,  367,
       86,   70,   79,  366,   81,   76,   72,   71,  165,   71,
       75,   74,   74,   73,   88,   77,  171,   88,   74,   75,
       75,   75,  280,   74,  182,   78,   77,   79,   80,   81,
       87,   87,   87,   95,   98,   98,   95,   98,  101,  102,

      102,  101,  102,  104,  104,  176,  104,  105,  105,  177,
      105,  108,  108,  165,  108,  110,  110,  328,  110,  112,
      112,  171,  112,  113,  113,  280,  113,  115,  115,  179,
      115,  117,  117,  363,  117,  118,  118,  362,  118,  120,
      120,  176,  120,  121,  121,  177,  121,  123,  123,  328,
      123,  125,  125,  205,  125,  127,  127,  127,  128,  128,
      179,  128,  130,  130,  205,  130,  183,  127,  195,  131,
      131,  131,  132,  195,  132,  132,  132,  133,  206,  133,
      127,  131,  133,  133,  133,  361,  132,  136,  136,  206,
      136,  200,  138,  138,  131,  138,  200,  139,  139,  132,

      139,  140,  140,  183,  140,  142,  142,  360,  142,  143,
      143,  359,  143,  145,  145,  325,  145,  146,  146,  272,
      146,  147,  147,  149,  147,  316,  149,  150,  150,  150,
      151,  154,  154,  151,  154,  157,  157,  358,  157,  285,
      149,  149,  149,  159,  159,  209,  159,  151,  151,  151,
      162,  162,  272,  162,  185,  185,  209,  185,  187,  187,
      325,  187,  188,  188,  159,  188,  190,  190,  316,  190,
      192,  192,  193,  192,  197,  193,  285,  197,  193,  199,
      199,  201,  199,  201,  201,  207,  201,  201,  201,  201,
      202,  274,  202,  202,  202,  203,  207,  208,  210,  211,

      203,  212,  202,  202,  202,  227,  227,  227,  208,  210,
      211,  213,  212,  202,  202,  202,  202,  202,  202,  203,
      215,  214,  213,  216,  217,  218,  220,  219,  221,  208,
      207,  215,  214,  274,  216,  217,  218,  220,  219,  221,
      222,  223,  224,  212,  210,  226,  228,  225,  226,  228,
      276,  222,  223,  224,  356,  295,  213,  214,  225,  221,
      295,  218,  215,  219,  217,  229,  229,  229,  230,  233,
      278,  230,  233,  355,  223,  235,  235,  354,  235,  238,
      238,  351,  238,  295,  225,  333,  241,  241,  224,  241,
      243,  243,  283,  243,  245,  245,  276,  245,  247,  247,

      249,  247,  249,  278,  277,  249,  249,  249,  250,  250,
      279,  250,  252,  252,  252,  253,  253,  253,  254,  254,
      254,  281,  257,  257,  252,  257,  259,  259,  273,  259,
      261,  261,  282,  261,  283,  263,  263,  252,  263,  265,
      265,  267,  265,  284,  267,  268,  268,  268,  269,  269,
      277,  269,  275,  275,  281,  275,  279,  286,  267,  267,
      267,  287,  287,  297,  287,  273,  296,  298,  299,  300,
      273,  301,  302,  282,  297,  273,  303,  296,  298,  299,
      300,  305,  301,  302,  284,  332,  306,  303,  317,  329,
      304,  307,  305,  311,  311,  311,  286,  306,  314,  296,

      297,  304,  307,  315,  301,  297,  308,  321,  324,  298,
      297,  322,  323,  309,  299,  300,  326,  308,  302,  303,
      327,  330,  305,  304,  309,  312,  312,  312,  306,  317,
      319,  319,  307,  319,  331,  314,  334,  315,  357,  318,
      335,  334,  313,  308,  315,  336,  364,  337,  310,  321,
      324,  335,  309,  323,  338,  322,  336,  326,  337,  327,
      330,  339,  340,  341,  353,  338,  398,  331,  365,  342,
      343,  344,  339,  340,  341,  334,  345,  335,  348,  336,
      342,  343,  344,  346,  357,  349,  336,  345,  347,  348,
      337,  364,  350,  291,  346,  338,  349,  370,  353,  347,

      371,  365,  370,  350,  340,  398,  290,  341,  372,  289,
      342,  371,  343,  388,  271,  373,  344,  345,  374,  372,
      347,  375,  346,  256,  349,  350,  373,  376,  377,  374,
      378,  379,  375,  380,  371,  381,  382,  383,  376,  377,
      384,  378,  379,  385,  380,  389,  381,  382,  383,  392,
      388,  384,  393,  395,  385,  394,  397,  397,  399,  397,
      392,  401,  240,  393,  395,  402,  394,  375,  403,  403,
      383,  403,  401,  389,  407,  408,  402,  196,  180,  178,
      174,  382,  169,  394,  167,  407,  408,  164,  161,  393,
      156,  155,  135,  107,   94,  399,   63,   59,   42,   15,

      401,    0,  402,  410,  410,  410,  410,  410,  410,  410,
      410,  410,  410,  410,  411,  411,  411,  411,  411,  411,
      411,  411,  411,  411,  411,  412,  412,  412,  412,  412,
      412,  412,  412,  412,  412,  412,  413,    0,    0,  413,
        0,  413,  413,    0,  413,  414,    0,    0,    0,  414,
        0,  414,  414,    0,  414,  415,  415,  415,  415,  415,
        0,  415,  416,    0,    0,  416,  416,  416,  416,    0,
      416,  417,  417,  417,  417,  417,  417,  417,  417,  418,
        0,  418,  418,    0,  418,  419,  419,  419,  420,    0,
        0,    0,    0,  420,  421,  421,  421,  421,  421,  421,

      421,  421,  421,  421,  421,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409,  409,  409,  409,  409,  409,  409,  409,  409,  409,
      409
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
#line 2 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"

 /*
    csound_orc.l:

    Copyright (C) 2006
    John ffitch, Steven Yi

    This file is part of Csound.

    The Csound Library is free software; you can redistribute it
    and/or modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    Csound is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with Csound; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
    02110-1301 USA
*/

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <ctype.h>
#include "csoundCore.h"
#define YYSTYPE TREE*
#define YYLTYPE ORCTOKEN*
#define YY_DECL int yylex (YYLTYPE *lvalp, CSOUND *csound, yyscan_t yyscanner)
#include "csound_orc.h"
#include "corfile.h"
YYSTYPE *yylval_param;
YYLTYPE *yylloc_param;
ORCTOKEN *make_string(CSOUND *, char *);
extern ORCTOKEN *lookup_token(CSOUND *, char *, void *);
extern  void    *fopen_path(CSOUND *, FILE **, char *, char *, char *, int);
ORCTOKEN *new_token(CSOUND *csound, int type);
ORCTOKEN *make_int(CSOUND *, char *);
ORCTOKEN *make_num(CSOUND *, char *);
ORCTOKEN *make_token(CSOUND *, char *s);
ORCTOKEN *make_label(CSOUND *, char *s);
static void check_newline_for_label(char *pp, void* yyscanner);
#define udoflag csound->parserUdoflag
#define namedInstrFlag csound->parserNamedInstrFlag
#include "parse_param.h"

#define YY_EXTRA_TYPE  PARSE_PARM *
#define PARM    yyget_extra(yyscanner)

/* #define YY_INPUT(buf,result,max_size)  {\ */
/*     result = get_next_char(buf, max_size, yyg); \ */
/*     if ( UNLIKELY( result <= 0  )) \ */
/*       result = YY_NULL; \ */
/*     } */

#define YY_USER_INIT

struct yyguts_t;
ORCTOKEN *do_at(CSOUND *, int, struct yyguts_t*);
int get_next_char(char *, int, struct yyguts_t*);
#line 1137 "Engine/csound_orclex.c"

#line 1139 "Engine/csound_orclex.c"

#define INITIAL 0
#define line 1
#define sline 2
#define src 3
#define xstr 4
#define udodef 5
#define udoarg 6

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 98 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"

#line 1434 "Engine/csound_orclex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 410 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 409 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 99 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ } /* EATUP THIS PART OF WINDOWS NEWLINE */
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 101 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                       yyscanner);
                }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 104 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                       yyscanner);
                  return NEWLINE; }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 107 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  if (UNLIKELY(strchr(yytext, '\n')))
                    csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '(';
                }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 113 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ return ')'; }
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 114 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '[';
                }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 119 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ return ']'; }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 120 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '+';
                   }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 126 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '-';
                   }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 132 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '*';
                   }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 138 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '/';
                   }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 144 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '%';
                   }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 150 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '^';
                   }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 156 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '?';
                   }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 162 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ return ':'; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 163 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return ',';
                   }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 169 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '!'; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 174 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ return S_ELIPSIS; }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 175 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_NEQ; }
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 180 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_AND; }
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 185 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_OR; }
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 190 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_BITSHIFT_LEFT; }
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 195 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_BITSHIFT_RIGHT; }
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 200 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_LT; }
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 205 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_LE; }
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 210 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_EQ; }
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 215 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_ADDIN; }
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 220 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_SUBIN; }
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 225 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_MULIN; }
	YY_BREAK
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
#line 230 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_DIVIN; }
	YY_BREAK
case 31:
/* rule 31 can match eol */
YY_RULE_SETUP
#line 235 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     *lvalp = make_token(csound, "=");
                     (*lvalp)->type = '=';
                     return '='; }
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 242 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_GT; }
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 247 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return S_GE; }
	YY_BREAK
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
#line 252 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '|'; }
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 257 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '&'; }
	YY_BREAK
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
#line 262 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '#'; }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 267 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     //printf("convert ¬ to ~\n");
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '~'; }
	YY_BREAK
case 38:
/* rule 38 can match eol */
YY_RULE_SETUP
#line 273 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return '~'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 278 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = do_at(csound, 1, yyg); return INTEGER_TOKEN; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 279 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = do_at(csound, 0, yyg); return INTEGER_TOKEN; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 280 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ return T_MAPI; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 281 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ return T_MAPK; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 282 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = IF_TOKEN;
                  return IF_TOKEN; }
	YY_BREAK
case 44:
/* rule 44 can match eol */
YY_RULE_SETUP
#line 285 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                  *lvalp = make_token(csound, yytext);
                  unput('(');
                  (*lvalp)->type = IF_TOKEN;
                  return IF_TOKEN; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 293 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = THEN_TOKEN;
                  return THEN_TOKEN; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 296 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ITHEN_TOKEN;
                  return ITHEN_TOKEN; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 299 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = KTHEN_TOKEN;
                  return KTHEN_TOKEN; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 302 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ELSEIF_TOKEN;
                  return ELSEIF_TOKEN; }
	YY_BREAK
case 49:
/* rule 49 can match eol */
YY_RULE_SETUP
#line 305 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                  unput('(');
                  *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ELSEIF_TOKEN;
                  return ELSEIF_TOKEN; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 313 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ELSE_TOKEN;
                  return ELSE_TOKEN; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 316 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ENDIF_TOKEN;
                  return ENDIF_TOKEN; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 319 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ENDIF_TOKEN;
                  return ENDIF_TOKEN; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 322 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = UNTIL_TOKEN;
                  return UNTIL_TOKEN; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 325 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = WHILE_TOKEN;
                  return WHILE_TOKEN; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 328 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = DO_TOKEN;
                  return DO_TOKEN; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 331 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = OD_TOKEN;
                  return OD_TOKEN; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 334 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = OD_TOKEN;
                  return OD_TOKEN; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 338 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = GOTO_TOKEN;
                  return GOTO_TOKEN; };
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 341 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = IGOTO_TOKEN;
                  return IGOTO_TOKEN; };
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 344 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = KGOTO_TOKEN;
                  return KGOTO_TOKEN; };
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 348 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = SRATE_TOKEN;
                  return SRATE_TOKEN; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 351 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = KRATE_TOKEN;
                  return KRATE_TOKEN; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 354 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = KSMPS_TOKEN;
                  return KSMPS_TOKEN; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 357 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = NCHNLS_TOKEN;
                  return NCHNLS_TOKEN; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 360 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = NCHNLSI_TOKEN;
                  return NCHNLSI_TOKEN; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 363 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = A4_TOKEN;
                  return A4_TOKEN; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 366 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  namedInstrFlag = 1;
                  return INSTR_TOKEN;
                }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 370 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ENDIN_TOKEN;
                  return ENDIN_TOKEN; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 373 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(udodef);
                  return UDOSTART_DEFINITION;
                }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 376 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  *lvalp = new_token(csound, UDOEND_TOKEN); return UDOEND_TOKEN;
                }
	YY_BREAK
case 71:
/* rule 71 can match eol */
YY_RULE_SETUP
#line 380 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
/* VL: added extra checks for after the colon */         { char *pp = yytext;
                  while (*pp==' ' || *pp=='\t') pp++;
                  check_newline_for_label(pp, yyscanner);
                  *lvalp = make_label(csound, pp);
                  return LABEL_TOKEN;
               }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 387 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  PARM->xstrbuff = (char *)malloc(128);
                  PARM->xstrptr = 0; PARM->xstrmax = 128;
                  PARM->xstrbuff[PARM->xstrptr++] = '"';
                  PARM->xstrbuff[PARM->xstrptr] = '\0';
                  BEGIN(xstr);
                }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 395 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  BEGIN(INITIAL);
                  PARM->xstrbuff[PARM->xstrptr++] = '"';
                  PARM->xstrbuff[PARM->xstrptr] = '\0';
                  /* printf("xstrbuff:>>%s<<\n", PARM->xstrbuff); */
                  *lvalp = make_string(csound, PARM->xstrbuff);
                  free(PARM->xstrbuff);
                  return STRING_TOKEN;
                }
	YY_BREAK
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 405 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ /* The next two should be one case but I cannot get that to work */
                  if (UNLIKELY(PARM->xstrptr+2==PARM->xstrmax)) {
                      PARM->xstrbuff = (char *)realloc(PARM->xstrbuff,
                                                       PARM->xstrmax+=80);
                      csound->DebugMsg(csound,"Extending xstr buffer\n");
                  }
                  //csound->DebugMsg(csound,"Adding newline (%.2x)\n", yytext[0]);
                  PARM->xstrbuff[PARM->xstrptr++] = yytext[0];
                  PARM->xstrbuff[PARM->xstrptr] = '\0';
                }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 416 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 417 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ if (UNLIKELY(PARM->xstrptr+2==PARM->xstrmax)) {
                      PARM->xstrbuff = (char *)realloc(PARM->xstrbuff,
                                                       PARM->xstrmax+=80);
                      csound->DebugMsg(csound,"Extending xstr buffer\n");
                  }
                  //csound->DebugMsg(csound,"Adding (%.2x)\n", yytext[0]);
                  PARM->xstrbuff[PARM->xstrptr++] = yytext[0];
                  PARM->xstrbuff[PARM->xstrptr] = '\0';
                }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 427 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 428 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(udoarg);
                  *lvalp = lookup_token(csound, yytext, yyscanner);
                  /* csound->Message(csound,"%s -> %d\n",
                                     yytext, (*lvalp)->type); */
                  return (*lvalp)->type; }
	YY_BREAK
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 433 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                     if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                     return ',';
                   }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 439 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(udoarg);
                  *lvalp = lookup_token(csound, yytext, yyscanner);
                  /* csound->Message(csound,"%s -> %d\n",
                                     yytext, (*lvalp)->type); */
                  return (*lvalp)->type; }
	YY_BREAK
case 81:
/* rule 81 can match eol */
YY_RULE_SETUP
#line 444 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(INITIAL);
                   csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                        yyscanner);
                  return NEWLINE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 450 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ /* String decode by c-code not rexp */
                  int cnt = 80;
                  char *buff = malloc(cnt);
                  int n = 1;
                  int ch;
                  buff[0] = '"';
                  for (;;) {
                    ch = input(yyscanner);
                    if (ch=='"') {
                      if (n>=cnt-2) buff = realloc(buff, cnt+=20);
                      buff[n++] = ch;
                      buff[n] = '\0';
                      break;
                    }
                    else if (ch=='\\') {
                      ch = input(yyscanner);
                      switch (ch) {
                      case 'a': case 'b': case 'n': case 'r':
                      case 't': case '\\':
                        if (n>=cnt-2) buff = realloc(buff, cnt+=20);
                        buff[n++] = '\\'; buff[n++]= ch;
                        break;
                        /* VL - 21-1-17 fix for octals in strings */
                      case '0':case '1':case '2':case '3':
                      case '4':case '5':case '6':case '7':
                        if (n>=cnt-2) buff = realloc(buff, cnt+=20);
                        buff[n++] = '\\'; buff[n++]= ch;
                        break;
                      default:
                        if (n>=cnt-2) buff = realloc(buff, cnt+=20);
                        buff[n++] = ch;
                        break;
                      }
                    }
                    else if (UNLIKELY(ch=='\n')) {
                      if (UNLIKELY(n>=cnt-2)) buff = realloc(buff, cnt+=20);
                      buff[n++] = '"';
                      buff[n] = '\0';
                      csound->Message(csound,
                              Str("unterminated string found on line %d >>%s<<\n"),
                                      csound_orcget_lineno(yyscanner), buff);
                      break;
                    }
                    else {
                      if (UNLIKELY(n>=cnt-2)) buff = realloc(buff, cnt+=20);
                      buff[n++] = ch;
                    }
                  }
                  *lvalp = make_string(csound, buff);
                  free(buff);
                  return (STRING_TOKEN);
                }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 503 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_token(csound, yytext);
                  (*lvalp)->type = ZERODBFS_TOKEN;
                  /* csound->Message(csound,"%d\n", (*lvalp)->type); */
                  return ZERODBFS_TOKEN; }
	YY_BREAK
case 84:
/* rule 84 can match eol */
YY_RULE_SETUP
#line 507 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ if (UNLIKELY(strchr(yytext, '\n')))
                       csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),
                                            yyscanner);
                  *strrchr(yytext, '(') = '\0';
                  *lvalp = lookup_token(csound, yytext, yyscanner);
                  return (*lvalp)->type+1; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 513 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = lookup_token(csound, yytext, yyscanner);
                  /* csound->Message(csound,"%s -> %d\n",
                                     yytext, (*lvalp)->type); */
                  return (*lvalp)->type; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 517 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  if (udoflag == 0) {
                        *lvalp = make_string(csound, yytext);
                        (*lvalp)->type = UDO_ANS_TOKEN;
                    } else if (udoflag == 1) {
                        *lvalp = make_string(csound, yytext);
                        (*lvalp)->type = UDO_ARGS_TOKEN;
                    } else {
                        *lvalp = make_int(csound, yytext); return (INTEGER_TOKEN);
                    }

                    csound->Message(csound,"%d\n", (*lvalp)->type);
                    return ((*lvalp)->type);
                }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 531 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ *lvalp = make_num(csound, yytext); return (NUMBER_TOKEN); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 532 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 534 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(sline); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 535 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ csound_orcset_lineno(atoi(yytext), yyscanner); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 536 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(INITIAL);}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 537 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(line); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 539 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
/* eat the whitespace */
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 540 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ csound_orcset_lineno(atoi(yytext), yyscanner); }
	YY_BREAK
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
#line 541 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{BEGIN(INITIAL);}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 543 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(src); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 545 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
/* eat the whitespace */
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 546 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ PARM->locn = atoll(yytext); }
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 547 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{ BEGIN(INITIAL); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 549 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  { int c = yytext[0]&0xff;
                    printf("Error: character %c(%.2x)\n", c, c);
                  }
                  return ERROR_TOKEN;
                }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(line):
case YY_STATE_EOF(sline):
case YY_STATE_EOF(src):
case YY_STATE_EOF(xstr):
case YY_STATE_EOF(udodef):
case YY_STATE_EOF(udoarg):
#line 556 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
{
                  yyterminate();
                }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 560 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"
ECHO;
	YY_BREAK
#line 2386 "Engine/csound_orclex.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 410 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 410 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 409);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 560 "/build/csound/src/csound-6.18.1/Engine/csound_orc.lex"


  /* unused at the moment
static inline int isNameChar(int c, int pos)
{
    c = (int) ((unsigned char) c);
    return (isalpha(c) || (pos && (c == '_' || isdigit(c))));
}
  */

ORCTOKEN *new_token(CSOUND *csound, int type)
{
    ORCTOKEN *ans = (ORCTOKEN*)csound->Calloc(csound, sizeof(ORCTOKEN));
    ans->type = type;
    return ans;
}

ORCTOKEN *make_token(CSOUND *csound, char *s)
{
    ORCTOKEN *ans = new_token(csound, STRING_TOKEN);
    ans->lexeme = cs_strdup(csound, s);
    return ans;
}

ORCTOKEN *make_label(CSOUND *csound, char *s)
{
    ORCTOKEN *ans = new_token(csound, LABEL_TOKEN);
    int len;
    char *ps = s;
    while (*ps != ':') ps++;
    *(ps+1) = '\0';
    len = strlen(s);
    ans->lexeme = (char*)csound->Calloc(csound, len);
    strNcpy(ans->lexeme, s, len); /* Not the trailing colon */
    return ans;
}

static void check_newline_for_label(char*s, void* yyscanner) {
    char *ps = s;
    while (*ps != ':') ps++;
    while(*ps != '\0') {
      if (*ps=='\n')
        csound_orcset_lineno(1+csound_orcget_lineno(yyscanner),yyscanner);
      ps++;
    }
}

ORCTOKEN *make_string(CSOUND *csound, char *s)
{
    ORCTOKEN *ans = new_token(csound, STRING_TOKEN);
    int len = strlen(s);
/* Keep the quote marks */
    ans->lexeme = (char*)csound->Calloc(csound, len + 1);
    strcpy(ans->lexeme, s);
    //printf(">>%s<<\n", ans->lexeme);
    return ans;
}

ORCTOKEN *do_at(CSOUND *csound, int k, struct yyguts_t *yyg)
{
    int n, i = 1;
    ORCTOKEN *ans;
    char buf[16];
    char *s = yytext;
    int len;
    while (*s=='@') s++;
    n = atoi(s);
    while (i<=n-k && i< 0x4000000) i <<= 1;
    ans = new_token(csound, INTEGER_TOKEN);
    sprintf(buf, "%d", i+k);
    len = strlen(buf);
    ans->lexeme = (char*)csound->Calloc(csound, len + 1);
    strNcpy(ans->lexeme, buf, len+1);
    ans->value = i;
    return ans;
}

ORCTOKEN *make_int(CSOUND *csound, char *s)
{
    int n = atoi(s);
    ORCTOKEN *ans = new_token(csound, INTEGER_TOKEN);
    int len = strlen(s);
    ans->lexeme = (char*)csound->Calloc(csound, len + 1);
    strNcpy(ans->lexeme, s, len+1);
    ans->value = n;
    return ans;
}

ORCTOKEN *make_num(CSOUND *csound, char *s)
{
    double n = atof(s);
    ORCTOKEN *ans = new_token(csound, NUMBER_TOKEN);
    int len = strlen(s);
    ans->lexeme = (char*)csound->Calloc(csound, len + 1);
    strNcpy(ans->lexeme, s, len+1);
    ans->fvalue = n;
    return ans;
}

char *csound_orcget_current_pointer(void *yyscanner)
{
    struct yyguts_t *yyg  = (struct yyguts_t*)yyscanner;
    return yyg->yy_c_buf_p;
}

uint64_t csound_orcget_locn(void *yyscanner)
{
//    struct yyguts_t *yyg  = (struct yyguts_t*)yyscanner;
    return PARM->locn;
}

void csound_orcput_ilocn(void *yyscanner, uint64_t num, uint64_t fil)
{
//    struct yyguts_t *yyg  = (struct yyguts_t*)yyscanner;
    PARM->iline = num;
    PARM->ilocn = fil;
}

uint64_t csound_orcget_iline(void *yyscanner)
{
//    struct yyguts_t *yyg  = (struct yyguts_t*)yyscanner;
    return PARM->iline;
}

uint64_t csound_orcget_ilocn(void *yyscanner)
{
//    struct yyguts_t *yyg  = (struct yyguts_t*)yyscanner;
    return PARM->ilocn;
}
/*
{STRCONSTe}     { *lvalp = make_string(csound, yytext);
                  csound->Message(csound,
                          Str("unterminated string found on line %d >>%s<<\n"),
                          csound_orcget_lineno(yyscanner),
                          yytext);
                  return (STRING_TOKEN); }
STRCONSTe \"(\.|[^\"])$
STRCONST        \"(\\.|[^\"\n])*\"
*/

